@@ -20,7 +20,7 @@ use Exporter::Shiny qw(
     default_profile
 );
 
-our $VERSION = '0.090001'; # TRIAL
+our $VERSION = '0.090002'; # TRIAL
 our %EXPORT_TAGS = (
     ini  => [qw( read_file read_string read_handle )],
     aws  => [qw( config_file default_profile credentials_file )],
@@ -51,7 +51,7 @@ my $prepare = sub {
         return \@lines;
     }
 
-    return [ map { chomp; $_ } $input->getlines ]
+    return [ map { s/\R$//; $_ } $input->getlines ]
         if Scalar::Util::openhandle( $input );
 
     if ( Ref::Util::is_blessed_ref $input ) {
@@ -64,7 +64,7 @@ my $prepare = sub {
         Carp::croak 'Cannot read from objects of type ' . ref $input;
     }
 
-    return [ split /\n/, ${ $input } ] if Ref::Util::is_scalarref $input;
+    return [ split /\R/, ${ $input } ] if Ref::Util::is_scalarref $input;
     return $input                      if Ref::Util::is_arrayref  $input;
 
     Carp::croak "Could not use $input as source for " . (caller(1))[3];
@@ -82,7 +82,7 @@ my $read = sub {
     my $profile = q{};
     for my $i (0 .. $#{$lines}) {
         my $line = $lines->[$i];
-        chomp $line;
+        $line =~ s/\R$//;
 
         if ($line =~ /^\[(?:profile )?([\w-]+)\]/) {
             $profile = $1;
@@ -99,18 +99,10 @@ my $read = sub {
             $nested->{$key} = $value;
         }
         else {
-            if ($value) {
-                $hash->{$profile}{$key} = $value;
-            }
-            else {
-                my ($next_indent) = $lines->[$i + 1] =~ /^(\s*)/;
-                if (length $next_indent) {
-                    $hash->{$profile}{$key} = $nested;
-                }
-                else {
-                    $hash->{$profile}{$key} = $value;
-                }
-            }
+            # Add nested hash if the value is empty and next line is indented.
+            $hash->{$profile}{$key} =
+                !length $value && $lines->[$i + 1] =~ /^\s+/ ? $nested : $value;
+
             $nested = {} if keys %{$nested};
         }
     }
@@ -157,13 +149,13 @@ sub read_file {
 sub read_string {
     Carp::croak 'String is missing' unless @_ >= 1;
     Carp::croak 'Argument was not a string' if Ref::Util::is_ref $_[0];
-    $read->( [ split /\n/, shift // '' ], @_ );
+    $read->( [ split /\R/, shift // '' ], @_ );
 }
 
 sub read_handle {
     Carp::croak 'Handle is missing' unless @_ >= 1;
     Carp::croak 'Argument was not a handle' unless Scalar::Util::openhandle( $_[0] );
-    $read->( [ map { s/\015?\012/\n/; chomp; $_ } shift->getlines ], @_ );
+    $read->( [ map { s/\R$//; $_ } shift->getlines ], @_ );
 }
 
 1;
